#include "common/iptables.h"

#define IPTABLES_MODULE_NAME IPTABLES_NAT64_MODULE_NAME
#define IPTABLES_MODULE_TYPE XT_NAT64
#include "common.c"
